==> open5gs_2.2.6.tar.xz: BUILD/docs/_docs/hardware/01-genodebs.md <==
---
title: eNodeBs / gNodeBs tested on Open5GS
head_inline: "<style> .blue { color: blue; } .bold { font-weight: bold; } </style>"
---

This page lists Radio hardware that has been tested by members of the Open5GS community,

Listed eNodeBs have at a minimum connected to Open5GS. This does not mean all functionality (dedicated bearers, GBRs, etc) has been tested.

If you have tested radio hardware from a vendor not listed with Open5GS, please add it to this page [by creating a PR on GitHub.](https://github.com/open5gs/open5gs)

### Commercial Macro BTS
---

 * Huawei BTS 3900 (S/W version V100R011C10SPC230)

### Small Cells
---

 * Baicells Neutrino
 * Baicells Nova 243
 * Baicells Nova 246
 * Baicells Nova 436Q
 * Baicells Nova 227 (EBS & CBRS)
 * Baicells Nova 233
 * Airspan AirSpeed 1030
 * Airspan AirHarmony 1000
 * AirHarmony 4000
 * AirHarmony 4200
 * AirHarmony 4400
 * Gemtek WLTGFC-101 (S/W version 2.1.1746.1116)
 * NOKIA FW2PC BC28 Flexi Zone G2 Outdoor Micro FDD LTE 700 MHz High Power
 * NOKIA FWH1 B38 Flexi Zone Outdoor Micro TD LTE 2600 MHz
 * Accelleran E1010 (LTE TDD B42)

### OpenRAN Hardware
---


### 4G/5G Software Stacks + SDRs
---

 * [srsLTE / srsENB](https://github.com/srsLTE/srsLTE) + LimeSDR, USRP, BladeRF x40 (BladeRF Not stable)
 * [Amarisoft](https://www.amarisoft.com/) + LimeSDR, USRP, Amarisoft PCI Express Card

### Misc Radio Hardware
---
 * [OsmoBTS](https://osmocom.org/projects/osmobts/wiki) controlled ip.access NanoBTS (Used for CSFB with Osmocom)
 * [UERANSIM](https://github.com/aligungr/UERANSIM) 5G RAN Simulator
 * [OpenAirInterface v1.0.3](https://gitlab.eurecom.fr/oai/openairinterface5g/-/tree/v1.0.3) 4G RAN Simulator

==> open5gs_2.2.9.tar.xz: BUILD/docs/_docs/hardware/01-genodebs.md <==
---
title: eNodeBs / gNodeBs tested on Open5GS
head_inline: "<style> .blue { color: blue; } .bold { font-weight: bold; } </style>"
---

This page lists Radio hardware that has been tested by members of the Open5GS community,

If you have tested radio hardware from a vendor not listed with Open5GS, please add it to this page [by creating a PR on GitHub.](https://github.com/open5gs/open5gs)

### Commercial 5G
---
 * Airspan 5G OpenRange vCU + Airspan 5G OpenRange vDU + Airspan 5G OpenRANGE06 AirVelocity 2700 RU
 * NOKIA AEQE (SW: 5G20A)
 * NOKIA AEQD (SW: 5G20A)

### Commercial 4G
---

 * Accelleran E1010 (LTE TDD B42)
 * AirHarmony 4000
 * AirHarmony 4200
 * AirHarmony 4400
 * Airspan AirSpeed 1030
 * Airspan AirHarmony 1000
 * Baicells Neutrino
 * Baicells Nova 243
 * Baicells Nova 246
 * Baicells Nova 436Q
 * Baicells Nova 227 (EBS & CBRS)
 * Baicells Nova 233
 * Gemtek WLTGFC-101 (S/W version 2.1.1746.1116)
 * Huawei BTS 3900 (S/W version V100R011C10SPC230)
 * NOKIA FW2PC BC28 Flexi Zone G2 Outdoor Micro FDD LTE 700 MHz High Power
 * NOKIA FWH1 B38 Flexi Zone Outdoor Micro TD LTE 2600 MHz

### 4G/5G Software Stacks + SDRs
---

 * [Amarisoft](https://www.amarisoft.com/) + LimeSDR, USRP, Amarisoft PCI Express Card
 * [srsLTE / srsENB](https://github.com/srsLTE/srsLTE) + LimeSDR, USRP, BladeRF x40 (BladeRF Not stable)

### Misc Radio Hardware
---
 * [OpenAirInterface v1.0.3](https://gitlab.eurecom.fr/oai/openairinterface5g/-/tree/v1.0.3) 4G RAN Simulator
 * [OsmoBTS](https://osmocom.org/projects/osmobts/wiki) controlled ip.access NanoBTS (Used for CSFB with Osmocom)
 * [UERANSIM](https://github.com/aligungr/UERANSIM) 5G RAN Simulator
